@@ -1,7 +1,7 @@
 import mlflow as __mlflow
 # -*- coding: utf-8 -*-
 
-"""Sidetrek __mlflow wrapper.
+"""Sidetrek mlflow wrapper.
 """
 # Simple calculator library
 
@@ -117,3 +117,6 @@ class ModelUtils:
         # set_tracking_uri(tracking_uri)
         ____mlflow.set_registry_uri
         print("Tracking uri can't be changed")
+
+
+model_utils = ModelUtils()
